==> open-xchange-core_6.22.0.orig.tar.bz2: open-xchange-core-6.22.0/com.openexchange.server/src/com/openexchange/groupware/calendar/CalendarCache.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.calendar;

import java.io.Serializable;
import org.apache.commons.logging.Log;
import com.openexchange.log.LogFactory;
import com.openexchange.caching.Cache;
import com.openexchange.caching.CacheService;
import com.openexchange.exception.OXException;
import com.openexchange.server.services.ServerServiceRegistry;


/**
 * {@link CalendarCache} - Cache for calendar module.
 *
 * @author <a href="mailto:martin.kauss@open-xchange.org">Martin Kauss</a>
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class CalendarCache {

    private static volatile CalendarCache instance;

    private static final String CACHE_NAME = "CalendarCache";

    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(CalendarCache.class));

    private Cache jcs;

    private CalendarCache() {
        try {
            try {
                jcs = ServerServiceRegistry.getInstance().getService(CacheService.class).getCache(CACHE_NAME);
            } catch (final OXException ce) {
                LOG.error("CalendarCache could not be initialized!", ce);
            }
        } catch (final Exception e) {
            LOG.error("CalendarCache could not be initialized!", e);
        }
    }

    public static CalendarCache getInstance() {
    	if (instance == null) {
        	synchronized (CalendarCache.class) {
        		if (instance == null) {
        			instance = new CalendarCache();
        		}
			}
        }
        return instance;
    }

    public void add(final Object key, final String groupKey, final Object o) throws OXException {
        jcs.putInGroup((Serializable) key, groupKey, (Serializable) o);
    }

    public Object get(final Object key, final String groupKey) {
        return jcs.getFromGroup((Serializable) key, groupKey);
    }

    public void clear() throws OXException {
        jcs.clear();
    }

    public void invalidateGroup(final int cid) {
        jcs.invalidateGroup(CalendarFolderObject.createGroupKeyFromContextID(cid));
    }

    public static boolean isInitialized() {
        return instance != null;
    }

}

==> open-xchange-core_7.4.0.orig.tar.bz2: open-xchange-core-7.4.0/com.openexchange.server/src/com/openexchange/groupware/calendar/CalendarCache.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.calendar;

import java.io.Serializable;
import org.apache.commons.logging.Log;
import com.openexchange.caching.Cache;
import com.openexchange.caching.CacheService;
import com.openexchange.exception.OXException;
import com.openexchange.log.LogFactory;
import com.openexchange.server.services.ServerServiceRegistry;


/**
 * {@link CalendarCache} - Cache for calendar module.
 *
 * @author <a href="mailto:martin.kauss@open-xchange.org">Martin Kauss</a>
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class CalendarCache {

    private static volatile CalendarCache instance;

    private static final String CACHE_NAME = "CalendarCache";

    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(CalendarCache.class));

    private Cache jcs;

    private CalendarCache() {
        try {
            try {
                jcs = ServerServiceRegistry.getInstance().getService(CacheService.class).getCache(CACHE_NAME);
            } catch (final OXException ce) {
                LOG.error("CalendarCache could not be initialized!", ce);
            }
        } catch (final Exception e) {
            LOG.error("CalendarCache could not be initialized!", e);
        }
    }

    public static CalendarCache getInstance() {
    	if (instance == null) {
        	synchronized (CalendarCache.class) {
        		if (instance == null) {
        			instance = new CalendarCache();
        		}
			}
        }
        return instance;
    }

    public void add(final Object key, final String groupKey, final Object o) throws OXException {
        jcs.putInGroup((Serializable) key, groupKey, (Serializable) o, false);
    }

    public Object get(final Object key, final String groupKey) {
        return jcs.getFromGroup((Serializable) key, groupKey);
    }

    public void clear() throws OXException {
        jcs.clear();
    }

    public void invalidateGroup(final int cid) {
        jcs.invalidateGroup(CalendarFolderObject.createGroupKeyFromContextID(cid));
    }

    public static boolean isInitialized() {
        return instance != null;
    }

}
